%Visualizing GPS Data
%=================
%JFriedman
%Oct 10/13
%=================
clear all; close all; clc; tic;

%load all data
load Garmin_ETREX_01.mat
X1 = DATA;
load Garmin_GPS76_01.mat
X2 = DATA;
load Garmin_GPS76_02.mat
X3 = DATA;
clear DATA

%combine data and remove all "Depths" > 25m
DATA = [X1;X2;X3];
finder = DATA(:,6) > 25;
DATA(finder,:) = [];

%make original plot of data
set(gcf,'position',[563  158 1060  800]);
set(gca,'fontsize',12,'linewidth',1.5,'color','w');
grid on; box on; hold on;
scatter(DATA(:,3),DATA(:,4),15,-DATA(:,6),'filled')
colorbar; title('Raw Echosounder Data','fontsize',16);
ylim([4.7824E6 4.7835E6]);
xlim([5.695E5 5.71E5]);
xlabel('X Coordinate (m, UTM 35T)','fontsize',14);
ylabel('Y Coordinate (m, UTM 35T)','fontsize',14);

set(gcf,'PaperPositionMode','auto')
print(gcf,'-dtiff','-zbuffer','-r400','Bathy_01');
close all

%countour data to check
F = TriScatteredInterp(DATA(:,3),DATA(:,4),DATA(:,6),'natural');
tx = [5.695E5:5:5.71E5];
ty = [4.7824E6:5:4.7835E6];

[qx,qy] = meshgrid(tx,ty);
qz = F(qx,qy);

set(gcf,'position',[563  158 1060  800]);
set(gca,'fontsize',12,'linewidth',1.5,'color','w');
grid on; box on; hold on;
surf(qx,qy,-qz); shading interp
plot(DATA(:,3),DATA(:,4),'xk','markersize',10);
colorbar; title('Initial Interpolation of Echosounder Data','fontsize',16);
ylim([4.7824E6 4.7835E6]);
xlim([5.695E5 5.71E5]);
xlabel('X Coordinate (m, UTM 35T)','fontsize',14);
ylabel('Y Coordinate (m, UTM 35T)','fontsize',14);

set(gcf,'PaperPositionMode','auto')
print(gcf,'-dtiff','-zbuffer','-r400','Bathy_02');
close all

%export data for MATLAB
save('BATHY','DATA');

%export data for text (Boyan)
fid = fopen('BATHY_BOYAN.txt','wt+');
fprintf(fid,'Date/Time, X (m, UTM35T), Y (m, UTM35T), DEP (m, below echsounder), ALT (m, from GPS)\n');
for ii = 1:length(DATA);
    fprintf(fid,'%s, %.3f, %.3f, %.3f, %.3f\n',datestr(DATA(ii,2),'yyyy/mm/dd HH:MM:SS'),DATA(ii,3),DATA(ii,4),-DATA(ii,6),DATA(ii,5));
end
fclose(fid);

%export data for Surfer
fid = fopen('BATHY_SURFER.txt','wt+');
for ii = 1:length(DATA);
    fprintf(fid,'%.3f, %.3f, %.3f\n',DATA(ii,3),DATA(ii,4),-DATA(ii,6));
end
fclose(fid);
toc;
